keywords = {'red', 'green', 'blue'};
descriptors = {'lab_hist9'};
N = 9;
% keyboard
s = samples(descriptors{1});
FontSize = 18;


% compute z values
z_values = computeZ(keywords, descriptors);



for i = 1:3
    fprintf('creating plot for keyword %s.\n', keywords{i});
    figure(i);

    % get z values for current keyword. set meaningless values to -Inf
    z = z_values{i};
    z(z==Inf) = -Inf;
    z(imag(z)>1e-6) = -Inf;
    
    % bin centers of Lab histogram
    L = 100*linspace(0, 1, N);
    a = 160*linspace(0, 1, N)-80;
    b = 160*linspace(0, 1, N)-80;
    minL = min(L); maxL = max(L);
    mina = min(a); maxa = max(a);
    minb = min(b); maxb = max(b);
    
	% get bin with maximum z value (index in histogram matrix)
    [maxz, idx] = max(z(:));
    idx = idx-1;
    bidx = floor(idx / N^2);
    aidx = idx - bidx*N^2;
    aidx = floor(aidx / N);
    Lidx = idx - bidx*N^2 - aidx*N;

    Lidx = Lidx + 1;
    aidx = aidx + 1;
    bidx = bidx + 1;
    
    % estimated Lab values for color defined by current keyword
    Lest = L(Lidx);
    aest = a(aidx);
    best = b(bidx);
    fprintf('zmax = %4.1f, L = %4.1f, a = %4.1f, b = %4.1f\n', maxz, Lest, aest, best);
    rgb = round(255*mexLab2sRGB([Lest aest best]));
    fprintf('R = %d, G = %d, B = %d\n', rgb(1), rgb(2), rgb(3));
    
    % color plane for bins with L = Lest
    s2 = reshape(s, N, N, N, 3);
    s2 = s2(Lidx, :, :, :);
    s2 = reshape(s2, N, N, 3);
    hold off
    surf(repmat(a', [1 N]), repmat(b, [N 1]), zeros(N), s2, 'facecolor', 'texture', 'LineStyle', 'none');
    hold on

    % z values in three orthogonal planes through maximum
    Lplane = reshape(z(Lidx, :, :), N, N, 1);
    aplane = reshape(z(:, aidx, :), N, N, 1);
    bplane = reshape(z(:, :, bidx), N, N, 1);
    
    surf(repmat(a', [1 N]), repmat(b, [N 1]), Lest*ones(N), Lplane, 'facecolor', 'texture', 'LineStyle', 'none');
    surf(aest*ones(N), repmat(b, [N 1]), repmat(L', [1 N]), aplane, 'facecolor', 'texture', 'LineStyle', 'none');
    surf(repmat(a, [N 1]), best*ones(N), repmat(L', [1 N]), bplane, 'facecolor', 'texture', 'LineStyle', 'none');
    colorbar
    
    % white lines at plane intersections
    plot3([aest aest], [best best], [minL maxL], 'w');
    plot3([mina maxa], [best best], [Lest Lest], 'w');
    plot3([aest aest], [minb maxb], [Lest Lest], 'w');

    % axis format
    xlabel('a', 'FontSize', FontSize);
    ylabel('b', 'FontSize', FontSize);
    zlabel('L', 'FontSize', FontSize);
    xlim([-80 80]);
    ylim([-80 80]);
    zlim([0 100]);    
    set(gca, 'XTick', [-80 -40 0 40 80], 'FontSize', FontSize);
    set(gca, 'YTick', [-80 -40 0 40 80], 'FontSize', FontSize);
    set(gca, 'ZTick', [0 20 40 60 80 100], 'FontSize', FontSize);
    
    title([keywords{i}], 'FontSize', FontSize);
    
    colormap gray
end




