function varargout = mydescribe(id, varargin)
% [desc1, desc2, ...] = mydescribe(id, name1, name2, ...)
% 
% computes descriptors (name1, name2, ...) for image given by id.
%
% examples: desc = mydescribe(1, 'lab_hist9');
%           [desc_lab, desc_ab] = mydescribe(1, 'lab_hist9', 'ab_hist21');


%% pre-processing
init;
argn = 1;

ALL = 0;
FORCE = opts.FORCE || opts.FORCE_DESCRIBE;
% FORCE = 1;

LD = size(varargin,2);
if (LD == 0)
    ALL = 1;
end

% descriptors the calling function wants to compute
wishlist = '';
for i = 1:LD
    wishlist = [wishlist '<' varargin{i} '>'];
end

% path of mat file where the descriptors are located on the hd
prefix = getPrefix(id);
dpath = sprintf(opts.descPath, prefix, num2str(id));
fprintf('%s ... ', dpath);

% create mat file if not existant
if ~exist(dpath, 'file')
    image_id = id;
    try
        save(dpath, 'image_id');
    catch % create directory if not existant
        directory = regexp(dpath, '.*\/\d\d\/', 'match');
        directory = directory{1};
        mkdir(directory);
        save(dpath, 'image_id');
    end
end

warning('off', 'MATLAB:load:variableNotFound');

%% descriptor computations
% try to load the descriptor first, if not existant compute it and save it
% for later use
% 
% you can implement your own descriptor by adding a new block, similar to
% the two you see here
name = 'lab_hist9';
if ~isempty(strfind(wishlist, ['<' name '>'])) || ALL
    wishlist = strrep(wishlist, ['<' name '>'], '');
    fprintf('%s ... ', name);
    load(dpath, name);
    if ~exist(name, 'var') || FORCE
        if ~exist('lab', 'var')
            lab = getImage(id, 'cielab');
        end
        [H, W, D] = size(lab);
        lab_ = reshape(lab, H*W, D);
        lab_hist9 = histnd(double(lab_), [[0 9 100]; [-80 9 80]; [-80 9 80]]);
        lab_hist9 = lab_hist9 / sum(lab_hist9(:));
        
        save(dpath, name, '-append');
    end
    varargout{argn} = lab_hist9;
    argn = argn + 1;
end

name = 'ab_hist21';
if ~isempty(strfind(wishlist, ['<' name '>'])) || ALL
    wishlist = strrep(wishlist, ['<' name '>'], '');
    fprintf('%s ... ', name);
    load(dpath, name);
    if ~exist(name, 'var') || FORCE
        if ~exist('lab', 'var')
            lab = getImage(id, 'cielab');
        end
%         keyboard
        [H, W, D] = size(lab);
        ab_ = reshape(lab(:,:,2:3), H*W, D-1);
        ab_hist21 = histnd(double(ab_), [[-80 21 80]; [-80 21 80]]);
        ab_hist21 = ab_hist21 / sum(ab_hist21(:));
        
        save(dpath, name, '-append');
    end
    varargout{argn} = ab_hist21;
end



if length(wishlist) >= 1
    error('unsupprted descriptor types: %s\n', wishlist);
end

fprintf('\n');
warning('on', 'MATLAB:load:variableNotFound');
