function data = getImage(id, type)
% data = getImage(id, type)
%
% get image id of specific type
%
% usage example:
% data = getImage(1, 'srgb')

init;
type = lower(type);
switch type
    case {'srgb'}
        fname = sprintf(opts.imagePath, getPrefix(id), num2str(id));
        fprintf('%s ... ', fname);
        if exist(fname, 'file')
            data = imread(fname);
            fprintf('loaded\n');
        else
            fprintf('\nfailed loading "%s" of id %0.0f (%s)\n', type, id, fname);
        end

	case {'cielab'}
        fname = sprintf(opts.charPath, type, getPrefix(id), num2str(id), 'mat');
        fprintf('%s ... ', fname);
        if exist(fname, 'file')
            load(fname);
            fprintf('loaded\n');
        else
            fprintf('computing %s\n', type);
            rgb = getImage(id, 'srgb');
            [~, ~, D] = size(rgb);
            if D==1
                fprintf('Single channel image. Copy channel 3 times.\n');
                rgb = cat(3, rgb, rgb, rgb);
            end
            data = mexsRGB2Lab(double(rgb)/255);
            % one can save the cielab image as a matrix on the HD for
            % future use, but this requires quite some disk space.
            % Uncomment the next line if you still want to do it.
            % save(fname, 'data');
        end
        
    otherwise
        error('myget: type "%s" is not supported\n', type);
end
