function h = histnd(data, bins)
% h = histnd(data, bins)
%
% Computes a N-dimensional histogram of values in data
% with binning defined in bins.
%
% data: LxN matrix with one N-dimensional data point in each of the L rows
% bins: Nx3 matrix defining the binning of dimension i in the i-th row
%       [[X1_min X1_numberOfBins X1_max];
%        [X2_min X2_numberOfBins X2_max];
%        ...                            ;
%        [XN_min XN_numberOfBins XN_max]]
%       Values outside the range Xi_min, Xi_max are added to the border bin
%
% h: output histogram with dimensions defined by the middle column in bins
%    X1_numberOfBins x X2_numberOfBins x ... x XN_numberOfBins
%
%
% example use:
% data = rand(10000, 3);
% bins = [[0 3 1]; [0 4 1]; [0 2 1]];
% h = histnd(data, bins);
%
% returns a 3x4x2 matrix with bin centers:
%   0.1667    0.5000    0.8333            along the 1st dimension
%   0.1250    0.3750    0.6250    0.8750  along the 2nd dimension
%   0.2500    0.7500                      along the 3rd dimension
%
%
% This is a mex file:
% 1) Compile this mex files for your system with the following command:
%    mex histnd.c computeHist.c
% 2) Copy the compiled executable in your path.
%
% You shoudl have received this matlab help file as part of a package that
% includes the corresponding c source code.
%
% If this is not the case or you have other questions, feel free to contact the author:
% Albrecht.Lindner@epfl.ch
